@@ -31,7 +31,7 @@ class UserLogin(APIView):  # 或继承APIView UpdateAPIView
         self.params = request.data  # 返回QueryDict类型
         # self.params = request.POST  # 返回QueryDict类型
         # self.params.update(request.data)
-        print("> UserLogin:", self.params)
+        # print("> UserLogin:", self.params)
         token = None
 
         try:
@@ -39,8 +39,7 @@ class UserLogin(APIView):  # 或继承APIView UpdateAPIView
             # account = str(self.params.get('account'))
             password = str(self.params.get('password', ''))
             # password = str(self.params.get('password'))
-            # platform = str(self.params.get('platform', ''))
-
+            platform = str(self.params.get('platform', ''))
 
             # 边界检查
             if not account:
@@ -61,15 +60,16 @@ class UserLogin(APIView):  # 或继承APIView UpdateAPIView
             account_serv, error_text = UserService.check_account(account)
             if error_text:
                 raise MyApiError(error_text, 6010)
-            print("> account_serv:", account_serv)
+            # print("> account_serv:", account_serv)
             user_id = account_serv['user_id']
 
-            auth_serv, error_text = UserService.check_login(user_id=user_id, password=password, account=account)
+            auth_serv, error_text = UserService.check_login(user_id=user_id, password=password, account=account,
+                                                            platform=platform)
             if error_text:
                 raise MyApiError(error_text, 6020)
             token = auth_serv['token']
 
-            print("> check:", auth_serv)
+            # print("> check:", auth_serv)
 
             res = {
                 'err': 0,
@@ -81,7 +81,7 @@ class UserLogin(APIView):  # 或继承APIView UpdateAPIView
             }
 
         except SyntaxError:
-            print(">SyntaxError:")
+            # print(">SyntaxError:")
             res = {
                 'err': 4001,
                 'msg': '语法错误',
