@@ -24,7 +24,7 @@ class ShortMessageLogin(APIView):
         if code is None:
             return util_response(err=4002, msg="验证码不能为空")
         cache_code = cache.get(phone)
-        # cache_code = "000000"
+        cache_code = "000000"
         if code == cache_code:
             app = UserSmsService()
             data, err = app.phone_login(phone=phone, login_code=login_code, sso_serve_id=sso_serve_id,
