@@ -86,6 +86,8 @@ class BaseInfo(models.Model):
     email = models.EmailField(verbose_name='邮箱', unique=True, blank=True, null=True, db_index=True, help_text='登录用的邮箱')
     wechat_openid = models.CharField(verbose_name='微信开放号', max_length=128, unique=True, blank=True, null=True,
                                      db_index=True, help_text='微信用户开放ID，注意openid是微信的专用名词')
+    wechat_appid = models.CharField(verbose_name='微信appid', max_length=128, unique=True, blank=True, null=True,
+                                     db_index=True)
     user_info = models.JSONField(verbose_name='用户信息', blank=True, null=True, help_text='用户扩展信息')
     register_time = models.DateTimeField(verbose_name='注册时间', default=timezone.now, help_text='')
 
@@ -96,13 +98,7 @@ class BaseInfo(models.Model):
 
     def __str__(self):
         # return f"{self.user_name}({self.full_name})"
-        return f"{self.user_name}"
-
-    def get_group_desc(self):
-        return self.user_group.description if self.user_group else ""
-
-    def get_permission_desc(self):
-        return self.permission.permission_name if self.permission else ""
+        return f"{self.full_name} ({self.user_name})"
 
 
 class Auth(models.Model):
@@ -129,12 +125,13 @@ class Auth(models.Model):
 
 
 class DetailInfo(models.Model):
+    sex_choices = [("0", "未知"), ("1", "男"), ("2", "女"), ]
     """ 3、User_Detail_Info 详细信息表 [1-1] """
     user = models.OneToOneField(BaseInfo, verbose_name='用户', unique=True, on_delete=models.DO_NOTHING,
                                 help_text='登录用的用户名')
     real_name = models.CharField(verbose_name='真实姓名', max_length=255, blank=True, null=True, db_index=True,
                                  help_text='实名认证后的真名')
-    sex = models.CharField(verbose_name='性别', max_length=1, blank=True, null=True, help_text='0未知 1男 2女')
+    sex = models.CharField(verbose_name='性别', max_length=1, blank=True, null=True, help_text='0未知 1男 2女', choices=sex_choices)
     birth = models.DateField(verbose_name='生日', blank=True, null=True, help_text='')
     tags = models.CharField(verbose_name='个人标签', max_length=255, blank=True, null=True, help_text='多个标签以英文;号为分隔符')
     signature = models.CharField(verbose_name='个性签名', max_length=255, blank=True, null=True, help_text='')
@@ -194,10 +191,13 @@ type_choices = (
 
 class ExtendField(models.Model):
     """ 4、User_Extend_Field 扩展字段表 [1-1] """
-    field = models.CharField(verbose_name='自定义字段', max_length=255, unique=True, blank=True, null=True, db_index=True, help_text='当已有字段不能满足的时候的扩展字段')
-    field_index = models.CharField(verbose_name='映射索引名', max_length=255, unique=True, blank=True, null=True, help_text='映射到扩展数据表的字段名，如：field_x')
+    field = models.CharField(verbose_name='自定义字段', max_length=255, unique=True, blank=True, null=True, db_index=True,
+                             help_text='当已有字段不能满足的时候的扩展字段')
+    field_index = models.CharField(verbose_name='映射索引名', max_length=255, unique=True, blank=True, null=True,
+                                   help_text='映射到扩展数据表的字段名，如：field_x')
     description = models.CharField(verbose_name='字段描述', max_length=255, blank=True, null=True, help_text='')
-    type = models.CharField(verbose_name='类型', max_length=255, blank=True, null=True, help_text='', choices=type_choices)
+    type = models.CharField(verbose_name='类型', max_length=255, blank=True, null=True, help_text='',
+                            choices=type_choices)
     config = models.JSONField(verbose_name='配置', blank=True, null=True, help_text='')
     default = models.CharField(verbose_name='默认值', max_length=255, blank=True, null=True, help_text='')
     sort = models.IntegerField(verbose_name='排序', blank=True, null=True, help_text='')
@@ -278,7 +278,8 @@ class Platform(models.Model):
 
 class PlatformsToUsers(models.Model):
     """ 9、*User_Platforms_To_Users - 多对多平台记录表 [N-N] """
-    user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, db_column='user_id', help_text='')
+    user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, db_column='user_id',
+                             help_text='')
     platform = models.ForeignKey(Platform, verbose_name='平台', on_delete=models.DO_NOTHING, help_text='')
     platform_user_id = models.BigIntegerField(verbose_name='平台用户ID', blank=True, null=True, db_index=True, help_text='')
 
@@ -323,8 +324,10 @@ class UserSsoServe(models.Model):
     sso_code = models.CharField(verbose_name='单点登录代码', max_length=255, blank=True, null=True, help_text='')
     sso_name = models.CharField(verbose_name='单点登录名', max_length=255, blank=True, null=True, help_text='')
     sso_url = models.CharField(verbose_name='单点登录地址', max_length=255, blank=True, null=True, help_text='')
+    sso_appid = models.CharField(verbose_name='appid', max_length=255, blank=True, null=True, help_text='')
     description = models.CharField(verbose_name='描述', max_length=255, blank=True, null=True, help_text='')
-
+    platform_user =models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, db_column='platform_user_id',
+                             help_text='')
     class Meta:
         db_table = 'user_sso_serve'
         verbose_name_plural = "11. 用户 - 单点登录服务表"
@@ -342,6 +345,7 @@ class UserSsoToUser(models.Model):
     sso_unicode = models.CharField(verbose_name='单点登录地址', max_length=255, blank=True, null=True, help_text='')
     sso_ticket = models.CharField(verbose_name='描述', max_length=255, blank=True, null=True, help_text='')
     app_id = models.CharField(verbose_name='服务授权app', max_length=255, blank=True, null=True, help_text='')
+    union_code = models.CharField(verbose_name='微信唯一ID', max_length=255, blank=True, null=True, help_text='')
 
     class Meta:
         db_table = 'user_sso_to_user'
@@ -354,8 +358,10 @@ class UserSsoToUser(models.Model):
 class UserRelateType(models.Model):
     """ 13、User_Relate_Type - 用户关系类型表 """
     id = models.AutoField(verbose_name='ID', primary_key=True)
-    relate_key = models.CharField(verbose_name='关系搜索key', max_length=50, blank=True, null=True, default="", help_text='')
-    relate_name = models.CharField(verbose_name='关系搜索名称', max_length=50, blank=True, null=True, default="", help_text='')
+    relate_key = models.CharField(verbose_name='关系搜索key', max_length=50, blank=True, null=True, default="",
+                                  help_text='')
+    relate_name = models.CharField(verbose_name='关系搜索名称', max_length=50, blank=True, null=True, default="",
+                                   help_text='')
     description = models.CharField(verbose_name='关系描述', max_length=255, blank=True, null=True, default="", help_text='')
 
     class Meta:
@@ -369,9 +375,12 @@ class UserRelateType(models.Model):
 class UserRelateToUser(models.Model):
     """ 14、User_Relate_To_User - 多对多关系类型表 """
     id = models.AutoField(verbose_name='ID', primary_key=True)
-    user = models.ForeignKey(to="BaseInfo", verbose_name='关系人', related_name="relate_user_id_alias", blank=True, null=True, help_text='', on_delete=models.DO_NOTHING)
-    with_user = models.ForeignKey(to="BaseInfo", verbose_name='关联关系人', related_name="relate_with_user_id_alias", blank=True, null=True, help_text='', on_delete=models.DO_NOTHING)
-    user_relate_type = models.ForeignKey(to=UserRelateType, verbose_name='关系类型ID', blank=True, null=True, help_text='', on_delete=models.DO_NOTHING)
+    user = models.ForeignKey(to="BaseInfo", verbose_name='关系人', related_name="relate_user_id_alias", blank=True,
+                             null=True, help_text='', on_delete=models.DO_NOTHING)
+    with_user = models.ForeignKey(to="BaseInfo", verbose_name='关联关系人', related_name="relate_with_user_id_alias",
+                                  blank=True, null=True, help_text='', on_delete=models.DO_NOTHING)
+    user_relate_type = models.ForeignKey(to=UserRelateType, verbose_name='关系类型ID', blank=True, null=True, help_text='',
+                                         on_delete=models.DO_NOTHING)
 
     class Meta:
         db_table = 'user_relate_to_user'
