@@ -12,7 +12,7 @@ from django.db.models import F
 from xj_role.services.role_service import RoleService
 from ..models import UserRelateType, UserRelateToUser, BaseInfo
 # 用户关系类型服务
-from ..utils.custom_tool import format_params_handle
+from ..utils.custom_tool import format_params_handle, format_list_handle
 
 
 class UserRelateTypeService():
@@ -82,21 +82,49 @@ class UserRelateTypeService():
 # 用户关系映射服务
 class UserRelateToUserService():
     @staticmethod
-    def list(params=None):
+    def list(params=None, filter_fields=None):
+        if filter_fields is None:
+            filter_fields = ["user_id", "with_user_id", "relate_type_name", "user_name", "with_user_name"]
         if params is None:
             params = {}
-        size = params.get("size", 10)
-        page = params.get("page", 20)
+
+        try:
+            size = int(params.get("size", 10))
+        except ValueError:
+            size = 10
+        try:
+            page = int(params.get("page", 1))
+        except ValueError:
+            page = 1
+
         try:
             need_pagination = 1 if int(params.get("need_pagination", 1)) else 0
         except Exception as e:
             need_pagination = 1
+        # 字段安全 过滤
+        default_fields = [
+            "user_id", "with_user_id", "user_relate_type_id", "relate_key", "relate_type_name",
+            "user_name", "full_name", "nickname", "with_user_name", "with_full_name", "with_nickname"
+        ]
+        filter_fields = format_list_handle(
+            param_list=filter_fields,
+            filter_filed_list=default_fields
+        )
         filter_params = format_params_handle(
             param_dict=params,
-            filter_filed_list=["user", "user_id", "with_user", "with_user_id", "user_relate_type", "user_relate_type_id"]
+            filter_filed_list=["user", "user_id", "user_id_list", "with_user", "with_user_id", "user_relate_type", "user_relate_type_id", "relate_key"],
+            alias_dict={"user_id_list": "user_id__in", "with_user_id_list": "with_user_id__in"}
         )
-        relate_user_obj = UserRelateToUser.objects.filter(**filter_params) \
-            .annotate(user_name=F("user__user_name")).annotate(with_user_name=F("with_user__user_name")).annotate(user_relate_type_name=F("user_relate_type__relate_name")).values()
+        relate_user_obj = UserRelateToUser.objects.annotate(
+            relate_key=F("user_relate_type__relate_key"),
+            relate_type_name=F("user_relate_type__relate_name"),
+            user_name=F("user__user_name"),
+            full_name=F("user__full_name"),
+            nickname=F("user__nickname"),
+            with_user_name=F("with_user__user_name"),
+            with_full_name=F("with_user__full_name"),
+            with_nickname=F("with_user__nickname"),
+        ).filter(**filter_params).values(*filter_fields)
 
         count = relate_user_obj.count()
         if need_pagination:
