@@ -2,24 +2,20 @@
 
 from datetime import datetime, timedelta
 from pathlib import Path
-# import os, logging, time, json, copy
 import re
 
 from django.contrib.auth.hashers import check_password
 from django.contrib.auth.hashers import make_password
-from django.core.paginator import Paginator
+from django.core.paginator import Paginator, EmptyPage
 from django.db.models import Q, F
-from django.forms import model_to_dict
 import jwt
-# from django.db.models import F
-# from rest_framework import exceptions
 from rest_framework import serializers
 
 from config.config import JConfig as MainConfig
 from main.settings import BASE_DIR
-from xj_user.services.user_detail_info_service import DetailInfoService
-from ..models import Auth, DetailInfo, ExtendField, Platform
+from ..models import Auth, Platform
 from ..models import BaseInfo
+from ..services.user_detail_info_service import DetailInfoService, get_short_id
 from ..utils.custom_tool import filter_result_field, format_params_handle, format_list_handle
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
@@ -108,30 +104,12 @@ class UserService:
 
         # 用户ID
         user_list = BaseInfo.objects.filter(Q(user_name=account) | Q(phone=account) | Q(email=account)) \
-            .annotate(user_id=F("id")) \
-            .values(
-            'user_id',
-            'user_name',
-            'full_name',
-            'nickname',
-            'phone',
-            'email',
-            'wechat_openid',
-            'user_info',
-            # 'user_group_id',
-            # 'user_group_value',
-            # 'permission_id',
-            # 'permission_value'
-        )
+            .annotate(user_id=F("id")).values('user_id', 'user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info')
         if not user_list.count():
             return None, "账户不存在"
         if user_list.count() > 1:
             return None, "登录异常，请联系管理员，发现多账号冲突："
-        # print("> user_list:", user_list)
         user_set = user_list.first()
-
-        # serializer = UserInfoSerializer(user_set, many=False)
-        # print("> serializer:", serializer)
         return user_set, None
 
     # 验证密码
@@ -283,68 +261,218 @@ class UserService:
 
     # 用户信息列表
     @staticmethod
-    def user_list(params=None, allow_user_list=None, ban_user_list=None, need_Pagination=True):
+    def user_list(params=None, allow_user_list=None, ban_user_list=None, need_Pagination=True, is_strict_mode=True):
+        """
+        用户基础信息列表服务
+        :param is_strict_mode: 是否是严格模式
+        :param params: 搜索字典参数 dict
+        :param allow_user_list: 允许用户ID列表 list
+        :param ban_user_list: 不允许用户ID列表 list
+        :param need_Pagination: 是否需要分页 bool
+        :return:  data,err
+        """
         if params is None:
             params = {}
-        user_base_set = BaseInfo.objects
         # 需要分页的时候
         page = params.get("page", 1)
         size = params.get("size", 20)
-        # is_admin = params.pop("is_admin", False)  # TODO 漏洞
 
+        # 用户信息排序
+        sort = params.get("sort", "-id")
+        sort = sort if sort in ["id", "-id", "register_time", "-register_time"] else "-id"
+
+        # ID列表 where in 搜索
+        search_params = format_params_handle(
+            param_dict=params,
+            filter_filed_list=["user_name", "email", "phone", "nickname", "full_name"],
+            alias_dict={
+                "user_name": "user_name__contains",
+                "email": "email__contains",
+                "phone": "phone__contains",
+                "nickname": "nickname__contains",
+                "full_name": "full_name__contains"
+            },
+            is_remove_empty=True,
+        )
         # 允许筛选的字段
-        user_name = params.get("user_name", None)
-        email = params.get("email", None)
-        phone = params.get("phone", None)
-        full_name = params.get("full_name", None)
-        nickname = params.get("nickname", None)
+        allow_user_list = [i for i in allow_user_list if i] if allow_user_list else None
+        ban_user_list = [i for i in ban_user_list if i] if ban_user_list else None
 
         # 开始按过滤条件
         try:
-            user_base_set = user_base_set.annotate(user_id=F("id"))
-            if allow_user_list:  # 筛选可以访问的列表
-                user_base_set = user_base_set.filter(user_id__in=allow_user_list)
+            user_base_set = BaseInfo.objects
 
-            if ban_user_list:  # 排除可以访问的列表
-                user_base_set = user_base_set.filter(~Q(user_id__in=ban_user_list))
+            user_base_set = user_base_set.extra(
+                select={'register_time': 'DATE_FORMAT(register_time, "%%Y-%%m-%%d %%H:%%i:%%s")'})
 
-            if user_name:
-                user_base_set = user_base_set.filter(user_name=user_name)
-            if email:
-                user_base_set = user_base_set.filter(email=email)
-            if phone:
-                user_base_set = user_base_set.filter(phone=phone)
-            if full_name:
-                user_base_set = user_base_set.filter(full_name__icontains=full_name)
-            if nickname:
-                user_base_set = user_base_set.filter(user_name__icontains=nickname)
-
-            user_base_set = user_base_set.values(
-                "user_id",
-                "email",
-                "full_name",
-                "user_name",
-                "nickname",
-                "phone",
-                "register_time",
-                "wechat_openid",
+            user_base_set = user_base_set.order_by(sort).annotate(user_id=F("id")).values(
+                "user_id", "email", "full_name", "user_name", "nickname", "phone", "register_time", "wechat_openid",
             )
+            if not allow_user_list is None and isinstance(allow_user_list, list):  # 筛选可以访问的列表
+                user_base_set = user_base_set.filter(user_id__in=allow_user_list)
+            if not ban_user_list is None and isinstance(ban_user_list, list):  # 排除可以访问的列表
+                user_base_set = user_base_set.filter(~Q(user_id__in=ban_user_list))
+            if search_params:  # 搜索条件
+                user_base_set = user_base_set.filter(**search_params)
+
             count = user_base_set.count()
-            # 查询保护，当超过100条的时候则需要分页查询
-            if not need_Pagination and count <= 100:
-                return list(user_base_set), None
+
+            # 是否分页，分情况查询
+            if need_Pagination:
+                # 需要分页支持全表搜索
+                paginator = Paginator(user_base_set, size)
+                try:
+                    page_set = paginator.page(page)
+                except EmptyPage:
+                    page_set = paginator.page(paginator.num_pages)
+                return {'size': int(size), 'page': int(page), 'count': count, 'list': list(page_set.object_list)}, None
+            else:
+                # 查询保护，当超过100条的时候则进行分页保护
+                if not search_params and not (ban_user_list and isinstance(ban_user_list, list)) and not (allow_user_list and isinstance(allow_user_list, list)):
+                    return [], None
+                if count <= 100:
+                    return list(user_base_set), None
+                if count >= 100 and is_strict_mode:
+                    return [], None
+                if count >= 100 and not is_strict_mode:
+                    page_set = Paginator(user_base_set, 100).page(1)
+                    return list(page_set.object_list), None
+
+                return [], None
         except Exception as e:
-            return None, "err:" + e.__str__()
-        page_set = Paginator(user_base_set, size).page(page)
-        page_list = []
-        if page_set:
-            page_list = list(page_set.object_list)
-        return {'size': int(size), 'page': int(page), 'count': count, 'list': page_list}, None
+            return [], "err:" + e.__str__()
+
+    @staticmethod
+    def user_add(params):
+        """
+        用户添加服务
+        :param params: 添加参数
+        :return: data,err
+        """
+        try:
+            account = str(params.get('account', ''))
+            password = str(params.get('password', ''))
+            full_name = str(params.get('full_name', ''))
+            nickname = str(params.get('nickname', ''))
+            # 边界检查
+            if not account:
+                return None, "account必填"
+            # 账号类型判断
+            if re.match(r'(^1[356789]\d{9}$)|(^\+?[78]\d{10}$)', account):
+                account_type = 'phone'
+            elif re.match(r'^\w+[\w\.\-\_]*@\w+[\.\w]*\.\w{2,}$', account):
+                account_type = 'email'
+            elif re.match(r'^[A-z\u4E00-\u9FA5]+\w*$', account):
+                account_type = 'username'
+            else:
+                return None, "账号必须是手机、邮箱格式或者为纯英文且不含特殊字符12位字符"
+            # 检查账号是否存在
+            user_list = None
+            if account_type == 'phone':
+                user_list = BaseInfo.objects.filter(Q(phone=account))
+            elif account_type == 'email':
+                user_list = BaseInfo.objects.filter(Q(email=account))
+            elif account_type == 'username':
+                user_list = BaseInfo.objects.filter(Q(user_name=account))
+
+            if user_list.count() and account_type == 'phone':
+                return None, "手机已被注册: " + account
+            elif user_list.count() and account_type == 'email':
+                return None, "邮箱已被注册: " + account
+            elif user_list.count() and account_type == 'username':
+                return None, "用户名已被注册: " + account
+
+            # 创建基础信息
+            base_info = {
+                'user_name': account if account_type == 'username' else get_short_id(),
+                'phone': account if account_type == 'phone' else "",
+                'email': account if account_type == 'email' else '',
+                'full_name': full_name,
+                "nickname": nickname,
+            }
+            current_user = BaseInfo.objects.create(**base_info)
+            # 创建登录信息
+            token = jwt.encode({'account': account}, jwt_secret_key)
+            auth = {
+                'user_id': current_user.id,
+                'password': make_password(password, None, 'pbkdf2_sha1'),
+                'plaintext': password,
+                'token': token,
+            }
+            Auth.objects.create(**auth)
+            return {"user_id": current_user.id}, None
+        except SyntaxError:
+            return None, "语法错误"
+        except LookupError:
+            return None, "无效数据查询"
+        except Exception as valueError:
+            return None, valueError.msg if hasattr(valueError, 'msg') else valueError.args
+        except:
+            return None, "未知错误"
+
+    @staticmethod
+    def user_edit(params=None, user_id=None):
+        """
+        用户基础信息修改服务。
+        PS:不允许修改用户的用户名，用户名负责登录作用
+        :param params: 修改参数集合
+        :param user_id: 用户ID
+        :return: None,err_msg
+        """
+        if params is None:
+            params = {}
+        if not user_id:
+            return None, "用户ID不存在"
+
+        # 绑定信息验重
+        email_other_user = BaseInfo.objects.exclude(id=user_id).filter(email=params.get("email", None)).first()
+        if params.get("email") and email_other_user:
+            return None, "当前邮箱被绑定"
+        phone_other_user = BaseInfo.objects.exclude(id=user_id).filter(phone=params.get("phone", None)).first()
+        if params.get("phone") and phone_other_user:
+            return None, "当前手机号被绑定"
+
+        # 用户基础信息中仅仅可以修改一下参数
+        # PS:邮箱和手机号不能为空，所以需要user_name不可修改，而且最初登录使用user_name。然后可以绑定
+        base_info_params = format_params_handle(
+            param_dict=params.copy(),
+            filter_filed_list=["full_name", "nickname", "user_info", "email", "phone"],
+            is_remove_null=True
+        )
+        # 更新基础信息
+        base_query_set = BaseInfo.objects.filter(id=user_id)
+        if not base_query_set.first():
+            return None, "用户不存在"
+        try:
+            base_query_set.update(**base_info_params)
+        except Exception as e:
+            return None, "修改异常：" + str(e)
+
+        # 详细信息
+        detail_info_params = format_params_handle(
+            param_dict=params.copy(),
+            remove_filed_list=["full_name", "nickname", "user_info"]
+        )
+        detail_info_params.setdefault("user_id", user_id)
+        data, err = DetailInfoService.create_or_update_detail(detail_info_params)
+        if err:
+            return None, "详情修改异常：" + err
+        return None, None
+
+    @staticmethod
+    def user_delete(id):
+        if not id:
+            return None, "ID 不能为空"
+        try:
+            BaseInfo.objects.filter(id=id).delete()
+        except Exception as e:
+            return None, e
+        return None, None
 
     @staticmethod
     def user_search(user_id_list: list = None, search_params: dict = None, need_map: bool = False, filter_fields: list = None):
         """
-        搜索用户，返回用户基础信息。服务调用不做接口
+        搜索用户，返回用户基础信息列表，没有分页限制。服务调用不做接口
         :param user_id_list: 用户id列表
         :param search_params: 搜素字段
         :param need_map: 是否需要映射
@@ -390,327 +518,3 @@ class UserService:
             return user_base_list, None
         except Exception as e:
             return [], "err:" + str(e)
-
-    @staticmethod
-    def user_add(params):
-        # 添加逻辑
-        try:
-            account = str(params.get('account', ''))
-            password = str(params.get('password', ''))
-            phone = str(params.get('phone', ''))
-            full_name = str(params.get('full_name', ''))
-            nickname = str(params.get('nickname', ''))
-
-            # 边界检查
-            if not account:
-                return None, "account必填"
-
-            # if not password:
-            #     return None, "密码必填"
-
-            # if not full_name:
-            #     return None, "full_name"
-
-            # 账号类型判断
-            if re.match(r'(^1[356789]\d{9}$)|(^\+?[78]\d{10}$)', account):
-                account_type = 'phone'
-            elif re.match(r'^\w+[\w\.\-\_]*@\w+[\.\w]*\.\w{2,}$', account):
-                account_type = 'email'
-            elif re.match(r'^[A-z\u4E00-\u9FA5]+\w*$', account):
-                account_type = 'username'
-            else:
-                return None, "账号必须是用户名、手机或者邮箱，用户名不能是数字开头"
-
-            # 检查账号是否存在
-            user_list = None
-            if account_type == 'phone':
-                user_list = BaseInfo.objects.filter(Q(phone=account))
-            elif account_type == 'email':
-                user_list = BaseInfo.objects.filter(Q(email=account))
-            elif account_type == 'username':
-                user_list = BaseInfo.objects.filter(Q(user_name=account))
-
-            if user_list.count() and account_type == 'phone':
-                return None, "手机已被注册: " + account
-            elif user_list.count() and account_type == 'email':
-                return None, "邮箱已被注册: " + account
-            elif user_list.count() and account_type == 'username':
-                return None, "用户名已被注册: " + account
-
-            # # 检查平台是否存在
-            # platform_id = None
-            # platform_set = Platform.objects.filter(platform_name__iexact=platform)
-            # if not platform_set.count() == 0:
-            #     platform_id = platform_set.first().platform_id
-
-            base_info = {
-                'user_name': account if account_type == 'username' else '',
-                'full_name': full_name,
-                "nickname": nickname,
-                'phone': account if account_type == 'phone' else phone,
-                'email': account if account_type == 'email' else '',
-            }
-            current_user = BaseInfo.objects.create(**base_info)
-            token = jwt.encode({'account': account}, jwt_secret_key)
-            auth = {
-                'user_id': current_user.id,
-                'password': make_password(password, None, 'pbkdf2_sha1'),
-                'plaintext': password,
-                'token': token,
-            }
-            Auth.objects.create(**auth)
-            # 用户绑定权限和部门
-
-            return {"user_id": current_user.id}, None
-        except SyntaxError:
-            return None, "语法错误"
-        except LookupError:
-            return None, "无效数据查询"
-        except Exception as valueError:
-            return None, valueError.msg if hasattr(valueError, 'msg') else valueError.args
-        except:
-            return None, "未知错误"
-        # 用户信息列表
-
-    @staticmethod
-    def user_basic_message(user_id=None, nickname=None, need_detail_info=True):
-        # 查找是否存在该用户
-        res_data = {}
-        if user_id:
-            user_basic_message = BaseInfo.objects.filter(id=user_id).annotate(user_id=F("id")).first()
-        elif nickname:
-            user_basic_message = BaseInfo.objects.filter(nickname=nickname).annotate(user_id=F("id")).first()
-        else:
-            # 没有输入搜索条件，非法调用直接返回空字典
-            return res_data, None
-
-        # 没有该用户的基础信息，是一个不存在的用户
-        if not user_basic_message:
-            return res_data, None
-
-        # 找到该用户的基础信息
-        res_data = model_to_dict(user_basic_message)
-
-        # 不需要拼接详细信息则直接返回
-        if not need_detail_info:
-            return res_data, None
-
-        # 拼接基础信息和用户详细信息
-        detail_info = DetailInfo.objects.filter(user_id=user_id).first()
-        if detail_info:
-            extend_field_list = ExtendField.objects.all().values("field_index", "field")
-            extend_field_map = {item["field_index"]: item["field"] for item in list(extend_field_list)}
-            detail_info = model_to_dict(detail_info)
-            [detail_alias_info] = filter_result_field(
-                [detail_info],
-                filter_filed_list=[i.name for i in DetailInfo._meta.fields if not i.name[0:6] == "field_"] + list(
-                    extend_field_map.keys()),
-                alias_dict=extend_field_map,
-            )
-            res_data.update(detail_alias_info)
-
-        # 返回基础和详细信息
-        return res_data, None
-
-    @staticmethod
-    def user_edit(params):
-        # 修改逻辑
-        try:
-            account = str(params.get('account', ''))
-            password = str(params.get('password', ''))
-            phone = str(params.get('phone', ''))
-            full_name = str(params.get('full_name', ''))
-            nickname = str(params.get('nickname', ''))
-            user_id = params.get('user_id', '')
-
-            # 边界检查
-            if not account:
-                return None, "account必填"
-
-            # if not password:
-            #     return None, "密码必填"
-
-            # if not full_name:
-            #     return None, "full_name"
-            if not user_id:
-                return None, " 用户id不能为空"
-            # 账号类型判断
-            if re.match(r'(^1[356789]\d{9}$)|(^\+?[78]\d{10}$)', account):
-                account_type = 'phone'
-            elif re.match(r'^\w+[\w\.\-\_]*@\w+[\.\w]*\.\w{2,}$', account):
-                account_type = 'email'
-            elif re.match(r'^[A-z\u4E00-\u9FA5]+\w*$', account):
-                account_type = 'username'
-            else:
-                return None, "账号必须是用户名、手机或者邮箱，用户名不能是数字开头"
-
-            # 检查账号是否存在
-            user_list = None
-            if account_type == 'phone':
-                user_list = BaseInfo.objects.filter(Q(phone=account), ~Q(id=user_id))
-            elif account_type == 'email':
-                user_list = BaseInfo.objects.filter(Q(email=account), ~Q(id=user_id))
-            elif account_type == 'username':
-                user_list = BaseInfo.objects.filter(Q(user_name=account), ~Q(id=user_id))
-            if user_list.count() and account_type == 'phone':
-                return None, "手机已被注册: " + account
-            elif user_list.count() and account_type == 'email':
-                return None, "邮箱已被注册: " + account
-            elif user_list.count() and account_type == 'username':
-                return None, "用户名已被注册: " + account
-
-            # # 检查平台是否存在
-            # platform_id = None
-            # platform_set = Platform.objects.filter(platform_name__iexact=platform)
-            # if not platform_set.count() == 0:
-            #     platform_id = platform_set.first().platform_id
-
-            base_info = {
-                'user_name': account if account_type == 'username' else '',
-                'full_name': full_name,
-                "nickname": nickname,
-                'phone': account if account_type == 'phone' else phone,
-                'email': account if account_type == 'email' else '',
-            }
-            BaseInfo.objects.filter(id=user_id).update(**base_info)
-
-            return {"user_id": user_id}, None
-        except SyntaxError:
-            return None, "语法错误"
-        except LookupError:
-            return None, "无效数据查询"
-        except Exception as valueError:
-            return None, valueError.msg if hasattr(valueError, 'msg') else valueError.args
-        except:
-            return None, "未知错误"
-
-    @staticmethod
-    def user_edit_v2(params=None, user_id=None):
-        """
-        用户修改服务。
-        PS：原本的代码逻辑复杂，而且不规范，为了大面积的受影响，开发二版本。
-        :param params: 修改参数集合
-        :param user_id: 用户ID
-        :return: None,err_msg
-        """
-        if params is None:
-            params = {}
-        if not user_id:
-            return None, "用户ID不存在"
-
-        # 绑定信息验重
-        email_other_user = BaseInfo.objects.exclude(id=user_id).filter(email=params.get("email", None)).first()
-        if params.get("email") and email_other_user:
-            return None, "当前邮箱被绑定"
-        phone_other_user = BaseInfo.objects.exclude(id=user_id).filter(phone=params.get("phone", None)).first()
-        if params.get("phone") and phone_other_user:
-            return None, "当前手机号被绑定"
-
-        # 用户基础信息中仅仅可以修改一下参数
-        # PS:邮箱和手机号不能为空，所以需要user_name不可修改，而且最初登录使用user_name。然后可以绑定
-        base_info_params = format_params_handle(
-            param_dict=params.copy(),
-            filter_filed_list=["full_name", "nickname", "user_info", "email", "phone"],
-            is_remove_null=True
-        )
-        # 更新基础信息
-        base_query_set = BaseInfo.objects.filter(id=user_id)
-        if not base_query_set.first():
-            return None, "用户不存在"
-        try:
-            base_query_set.update(**base_info_params)
-        except Exception as e:
-            return None, "修改异常：" + str(e)
-
-        # 详细信息
-        detail_info_params = format_params_handle(
-            param_dict=params.copy(),
-            remove_filed_list=["full_name", "nickname", "user_info"]
-        )
-        detail_info_params.setdefault("user_id", user_id)
-        data, err = DetailInfoService.create_or_update_detail(detail_info_params)
-        if err:
-            return None, err
-        return None, None
-
-    @staticmethod
-    def user_role_edit(params):
-        # 修改逻辑 TODO 为什么起这个名字，这个不是用户基础信息修改吗 BaseInfo.objects.filter(id=user_id).update(**base_info)
-        try:
-            account = str(params.get('account', ''))
-            phone = str(params.get('phone', ''))
-            full_name = str(params.get('full_name', ''))
-            nickname = str(params.get('nickname', ''))
-            user_id = params.get('user_id', '')
-            base_info = {}
-            if not user_id:
-                return None, " 用户id不能为空"
-            # 边界检查
-            if account:
-                # 账号类型判断
-                if re.match(r'(^1[356789]\d{9}$)|(^\+?[78]\d{10}$)', account):
-                    account_type = 'phone'
-                elif re.match(r'^\w+[\w\.\-\_]*@\w+[\.\w]*\.\w{2,}$', account):
-                    account_type = 'email'
-                elif re.match(r'^[A-z\u4E00-\u9FA5]+\w*$', account):
-                    account_type = 'username'
-                else:
-                    return None, "账号必须是用户名、手机或者邮箱，用户名不能是数字开头"
-                # 检查账号是否存在
-                user_list = None
-                if account_type == 'phone':
-                    user_list = BaseInfo.objects.filter(Q(phone=account), ~Q(id=user_id))
-                elif account_type == 'email':
-                    user_list = BaseInfo.objects.filter(Q(email=account), ~Q(id=user_id))
-                elif account_type == 'username':
-                    user_list = BaseInfo.objects.filter(Q(user_name=account), ~Q(id=user_id))
-                if user_list.count() and account_type == 'phone':
-                    return None, "手机已被注册: " + account
-                elif user_list.count() and account_type == 'email':
-                    return None, "邮箱已被注册: " + account
-                elif user_list.count() and account_type == 'username':
-                    return None, "用户名已被注册: " + account
-
-                base_info['user_name'] = account if account_type == 'username' else ''
-                base_info['phone'] = account if account_type == 'phone' else phone
-                base_info['email'] = account if account_type == 'email' else ''
-
-            if full_name:
-                base_info['full_name'] = full_name
-
-            if nickname:
-                base_info['nickname'] = nickname
-
-            BaseInfo.objects.filter(id=user_id).update(**base_info)
-
-            return {"user_id": user_id}, None
-        except SyntaxError:
-            return None, "语法错误"
-        except LookupError:
-            return None, "无效数据查询"
-        except Exception as valueError:
-            return None, valueError.msg if hasattr(valueError, 'msg') else valueError.args
-        except:
-            return None, "未知错误"
-
-    @staticmethod
-    def user_delete(id):
-        if not id:
-            return None, "ID 不能为空"
-        try:
-            BaseInfo.objects.filter(id=id).delete()
-        except Exception as e:
-            return None, e
-        return None, None
-
-    # 胡家萍 用户权限判断闭包
-    @staticmethod
-    def hjp_user_right_call(user_info):
-        # map = {1: "集团用户", 2: "村民用户没有权限"}
-        try:
-            if user_info[0]['user_group'] == 1:
-                return True
-            else:
-                return False
-        except Exception as e:
-            return False
