@@ -285,6 +285,8 @@ class WechatService:
             user_id=user_id,
             sso_serve__sso_appid=appid
         ).first()
+        if not sso_set:
+            return None, "平台用户信息不存在"
         sso_set = model_to_dict(sso_set)
         if not sso_set.get("union_code", None):
             UserSsoToUser.objects.filter(
