@@ -33,30 +33,30 @@ def parse_json(result):
     return result
 
 
-# 字段筛选并替换成sql表达式
-def only_filed_handle(res_json, only_filed, except_field_list, transform_field):
-    if res_json is None:
-        return None
-    if only_filed is None and except_field_list is None and transform_field is None:
-        return res_json
-    finish_set = {}
-    for k, v in res_json.items():
-        # 替换成条件语句如 gte,lte等等，重复匹配只按照第一个替换规则
-        if only_filed and k in only_filed.keys():
-            finish_set[only_filed[k]] = v
-        if transform_field and k in transform_field.keys():
-            finish_set[transform_field[k]] = v
-        if except_field_list and k in except_field_list:
-            finish_set.pop(k)
-    return finish_set
+# 字段筛选并替换成别名
+def format_params_handle(param_dict, filter_filed_list=None, remove_filed_list=None, alias_dict=None):
+    # 转换的数据类型不符合，直接返回出去
+    if not isinstance(param_dict, dict):
+        raise Exception("param_dict 必须是字典格式")
+
+    # 类型判断 过滤字段
+    if filter_filed_list and isinstance(filter_filed_list, list):
+        param_dict = {k: v for k, v in param_dict.copy().items() if k in filter_filed_list and v}
+
+    # 类型判断， 剔除字段
+    if remove_filed_list and isinstance(remove_filed_list, list):
+        param_dict = {k: v for k, v in param_dict.copy().items() if not k in remove_filed_list and v}
+
+    # 类型判断 字段转换
+    if alias_dict and isinstance(alias_dict, dict):
+        param_dict = {alias_dict.get(k, k): v for k, v in param_dict.copy().items()}
+
+    return param_dict
 
 
 # 请求参数解析
-def parse_data(request, only_field=None, except_field_list=None, transform_field=None):
+def parse_data(request, **kwargs):
     # 解析请求参数 兼容 APIView与View的情况，View 没有request.data
-    if only_field and not (isinstance(only_field, list) or isinstance(only_field, dict)):
-        raise Exception('parse_data方法only_field参数必须是字典或者列表格式')
-    only_field = {k: k for k in only_field} if isinstance(only_field, list) else only_field
     content_type = request.META.get('CONTENT_TYPE', "").split(";")[0]
     method = request.method
     if method == "GET":
@@ -68,7 +68,7 @@ def parse_data(request, only_field=None, except_field_list=None, transform_field
             data = request.POST
     else:
         data = request.data
-    return only_filed_handle(res_json={k: v for k, v in data.items()}, only_filed=only_field, except_field_list=except_field_list, transform_field=transform_field)
+    return {k: v for k, v in data.items()}
 
 
 # 模型解析
@@ -194,6 +194,7 @@ def model_delete(request, model, is_real_delete=True):
         # res = model.objects.filter(**from_data)
         if not res:
             return util_response('', 7557, "数据已不存在")
+
         res.delete()
     else:
         from_data['is_delete'] = 0
